"""哈希函数

· md5_hash
· sha256_hash
· sha512_hash

AES 加密

· aes_encrypt
· aes_decrypt

RSA 加密

· generate_rsa_keys
· rsa_encrypt
· rsa_decrypt

DES 加密

· des_encrypt
· des_decrypt

3DES 加密

· des3_encrypt
· des3_decrypt

ChaCha20 加密

· chacha20_encrypt
· chacha20_decrypt

数字签名

· sign_data
· verify_signature

工具函数

· bytes_to_base64
· base64_to_bytes
· generate_random_key"""